
===============================================
Automating Quantum Neural Networks Applications
===============================================

|

.. image:: https://readthedocs.org/projects/prevision-quantum-nn/badge/?version=latest
  :target: https://prevision-quantum-nn.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://img.shields.io/github/license/previsionio/prevision-quantum
  :alt: GitHub license
  :target: https://github.com/previsionio/prevision-quantum/blob/master/LICENSE

.. image:: docs/source/_static/prevision-quantum.png
  :width: 70%
  :align: center

Prevision-quantum-nn is a library that allows to handle automatically quantum variational circuits.
It is developed by `prevision.io <https://prevision.io/>`_.

It is built over `pennylane <https://pennylane.ai/>`_, developped by `Xanadu <https://www.xanadu.ai/>`_.

For further information on the usage of the library, refer to the `documentation <https://prevision-quantum-nn.readthedocs.io/en/latest/index.html#>`_.
